==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/app_api/l10n/vi.js <==
OC.L10N.register(
    "app_api",
    {
    "Update to {version}" : "Cập nhật tới {version}",
    "Remove" : "Xoá",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ứng dụng này không thể được cài đặt vì các điều kiện phụ thuộc sau không được đáp ứng:",
    "View in store" : "Xem tại cửa hàng",
    "Visit website" : "Truy cập trang web",
    "Report a bug" : "Báo cáo lỗi",
    "User documentation" : "Tài liệu người dùng",
    "Admin documentation" : "Tài liệu quản trị",
    "Developer documentation" : "Tài liệu dành cho nhà phát triển",
    "{license}-licensed" : "{license}-được cấp phép",
    "This app is supported via your current Nextcloud subscription." : "Ứng dụng này được hỗ trợ thông qua thuê bao Nextcloud hiện tại của bạn.",
    "Supported" : "Đã hỗ trợ",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Các ứng dụng nổi bật được phát triển bởi và trong cộng đồng. Chúng cung cấp chức năng trung tâm và sẵn sàng để sử dụng trong sản xuất.",
    "Featured" : "Tính năng được trang bị",
    "Update to {update}" : "Cập nhật tới {update}",
    "Icon" : "Biểu tượng",
    "Name" : "Tên",
    "Version" : "Phiên bản",
    "Level" : "Cấp độ",
    "Actions" : "Hành động",
    "Results from other categories" : "Kết quả từ các danh mục khác",
    "_Update_::_Update all_" : ["Cập nhật tất cả"],
    "Type" : "Loại",
    "Cancel" : "Hủy",
    "Delete" : "Xóa",
    "Edit" : "Chỉnh sửa",
    "Host" : "Máy chủ",
    "Nextcloud URL" : "vWorkspace URL",
    "Enabled" : "Đá kích hoạt",
    "Confirm" : "Xác nhận",
    "Save" : "Lưu",
    "Register" : "Đăng ký",
    "Your apps" : "Ứng dụng của bạn",
    "Documentation" : "Tài liệu",
    "Details" : "Chi tiết",
    "Changelog" : "Sổ cập nhập thay đổi",
    "by {author}\n{license}" : "bởi {tác giả}{giấy phép}",
    "Active apps" : "Ứng dụng kích hoạt",
    "Disabled apps" : "Ứng dụng vô hiệu hóa",
    "Updates" : "Cập nhật",
    "Featured apps" : "Các ứng dụng đề xuất",
    "Supported apps" : "Ứng dụng được hỗ trợ",
    "Enable" : "Bật",
    "Disable" : "Tắt",
    "Allow untested app" : "Cho phép ứng dụng chưa được kiểm tra",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
    "An error occurred during the request. Unable to proceed." : "Đã xảy ra lỗi trong quá trình yêu cầu. Không thể tiếp tục.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Lỗi: Không thể kích hoạt ứng dụng này vì nó khiến máy chủ không ổn định"
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/app_api/l10n/vi.js <==
OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Hủy",
    "Delete" : "Xóa",
    "Edit" : "Chỉnh sửa",
    "Unlimited" : "Không giới hạn",
    "Name" : "Tên",
    "Host" : "Máy chủ",
    "Nextcloud URL" : "vWorkspace URL",
    "Enabled" : "Đá kích hoạt",
    "More information" : "Thêm thông tin",
    "Remove" : "Xoá",
    "From" : "Từ",
    "To" : "Tới",
    "Add" : "Thêm",
    "Confirm" : "Xác nhận",
    "Save" : "Lưu",
    "Register" : "Đăng ký",
    "{license}-licensed" : "{license}-được cấp phép",
    "Update to {version}" : "Cập nhật tới {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ứng dụng này không thể được cài đặt vì các điều kiện phụ thuộc sau không được đáp ứng:",
    "View in store" : "Xem tại cửa hàng",
    "Visit website" : "Truy cập trang web",
    "Report a bug" : "Báo cáo lỗi",
    "User documentation" : "Tài liệu người dùng",
    "Admin documentation" : "Tài liệu quản trị",
    "Developer documentation" : "Tài liệu dành cho nhà phát triển",
    "This app is supported via your current Nextcloud subscription." : "Ứng dụng này được hỗ trợ thông qua thuê bao Nextcloud hiện tại của bạn.",
    "Supported" : "Đã hỗ trợ",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Các ứng dụng nổi bật được phát triển bởi và trong cộng đồng. Chúng cung cấp chức năng trung tâm và sẵn sàng để sử dụng trong sản xuất.",
    "Featured" : "Tính năng được trang bị",
    "Update to {update}" : "Cập nhật tới {update}",
    "Icon" : "Biểu tượng",
    "Version" : "Phiên bản",
    "Level" : "Cấp độ",
    "Actions" : "Hành động",
    "Results from other categories" : "Kết quả từ các danh mục khác",
    "_Update_::_Update all_" : ["Cập nhật tất cả"],
    "Type" : "Loại",
    "by {author}\n{license}" : "bởi {tác giả}{giấy phép}",
    "Your apps" : "Ứng dụng của bạn",
    "Documentation" : "Tài liệu",
    "Details" : "Chi tiết",
    "Changelog" : "Sổ cập nhập thay đổi",
    "Active apps" : "Ứng dụng kích hoạt",
    "Disabled apps" : "Ứng dụng vô hiệu hóa",
    "Updates" : "Cập nhật",
    "Featured apps" : "Các ứng dụng đề xuất",
    "Supported apps" : "Ứng dụng được hỗ trợ",
    "Enable" : "Bật",
    "Disable" : "Tắt",
    "Allow untested app" : "Cho phép ứng dụng chưa được kiểm tra",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
    "An error occurred during the request. Unable to proceed." : "Đã xảy ra lỗi trong quá trình yêu cầu. Không thể tiếp tục.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Lỗi: Không thể kích hoạt ứng dụng này vì nó khiến máy chủ không ổn định"
},
"nplurals=1; plural=0;");
